@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.11';
+$Footprintless::Factory::VERSION = '1.12';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -91,7 +91,11 @@ sub _init {
         if ($plugin_modules) {
             foreach my $plugin_module (@$plugin_modules) {
                 $logger->debugf( 'registering plugin %s', $plugin_module );
-                $self->register_plugin( Footprintless::Util::dynamic_module_new($plugin_module) );
+                $self->register_plugin(
+                    Footprintless::Util::dynamic_module_new(
+                        $plugin_module, $self->{entities}{'footprintless'}{$plugin_module}
+                    )
+                );
             }
         }
     }
@@ -170,7 +174,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 DESCRIPTION
 
